@@ -90,12 +90,14 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
                
                if(length(ind.pos) > mmax) {
                  ind.pos = paste(paste(ind.pos[1:(mmax - 1)], collapse = "*, *"), ind.pos[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
-                 ind.neg = paste(paste(ind.neg[1:(mmax - 1)], collapse = "*, *"), ind.neg[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
                } else if(length(ind.pos) > 1) {
                  ind.pos = paste(paste(ind.pos[- length(ind.pos)], collapse = "*, *"), ind.pos[length(ind.pos)], sep = gettext("* and *",domain="R-FactoInvestigate"))
+               }
+               if(length(ind.neg) > mmax) {
+                 ind.neg = paste(paste(ind.neg[1:(mmax - 1)], collapse = "*, *"), ind.neg[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
+               } else if(length(ind.neg) > 1) {
                  ind.neg = paste(paste(ind.neg[- length(ind.neg)], collapse = "*, *"), ind.neg[length(ind.neg)], sep = gettext("* and *",domain="R-FactoInvestigate"))
                }
-               
                if(d %% 2 == 1) {
                  if(length(rownames(Idata)[Idata$clust %in% pos.groups]) != 0) {
                    if(length(rownames(Idata)[Idata$clust %in% pos.groups & rownames(Idata) %in% drawn]) != 0) {
@@ -303,7 +305,7 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
              # if(length(selec.row) > 100) {
              #   selec.row = names(sort(row.cos2, decreasing = TRUE))[1:100]
              # }
-             Idata = data.frame(rbind(res$row$coord[,dim], res$row.sup$coord[,dim]))
+             Idata = data.frame(rbind(res$row$coord[,dim], res$row.sup$coord[,dim,drop=FALSE]))
              if(length(selec.row) > 100) {
                row.hcpc = HCPC(data.frame(Idata[selec.row,]), kk = 100, consol = FALSE, graph = FALSE)
                Idata$clust = NA
@@ -311,8 +313,8 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
                last.clust = length(levels(row.hcpc$data.clust$clust)) + 1
                Idata[!rownames(Idata) %in% selec.row, "clust"] = last.clust
              } else if(length(selec.row) < 10) {
-               row.hcpc = HCPC(data.frame(Idata[selec.row,]), graph = FALSE)
-               Idata$clust = row.hcpc$data.clust$clust
+               row.hcpc = HCPC(data.frame(Idata), graph = FALSE)
+               Idata$clust <- row.hcpc$data.clust$clust
                last.clust = length(levels(row.hcpc$data.clust$clust)) + 1
              } else {
                row.hcpc = HCPC(data.frame(Idata[selec.row,]), graph = FALSE)
@@ -322,9 +324,8 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
                Idata[!rownames(Idata) %in% selec.row, "clust"] = last.clust
              }
              
-             
              Idata$clust = as.factor(Idata$clust)
-             CD.dim = catdes(Idata[Idata$clust != last.clust,], 3, proba = 0.15)
+             CD.dim = catdes(Idata[Idata$clust != last.clust,,drop=FALSE], 3, proba = 0.15)
              Itest = sapply(CD.dim$quanti, is.null)
              
              if(any(Itest)) { # identification des clusters non-caracteristiques du plan
@@ -352,9 +353,12 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
                
                if(length(ind.pos) > mmax) {
                  ind.pos = paste(paste(ind.pos[1:(mmax - 1)], collapse = "*, *"), ind.pos[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
-                 ind.neg = paste(paste(ind.neg[1:(mmax - 1)], collapse = "*, *"), ind.neg[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
                } else if(length(ind.pos) > 1) {
                  ind.pos = paste(paste(ind.pos[- length(ind.pos)], collapse = "*, *"), ind.pos[length(ind.pos)], sep = gettext("* and *",domain="R-FactoInvestigate"))
+               }
+               if(length(ind.neg) > mmax) {
+                 ind.neg = paste(paste(ind.neg[1:(mmax - 1)], collapse = "*, *"), ind.neg[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
+               } else if(length(ind.neg) > 1) {
                  ind.neg = paste(paste(ind.neg[- length(ind.neg)], collapse = "*, *"), ind.neg[length(ind.neg)], sep = gettext("* and *",domain="R-FactoInvestigate"))
                }
                
@@ -569,7 +573,7 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
                last.clust = length(levels(ind.hcpc$data.clust$clust)) + 1
                Idata[!rownames(Idata) %in% selec.ind, "clust"] = last.clust
              } else if(length(selec.ind) < 10) {
-               ind.hcpc = HCPC(data.frame(Idata[selec.ind,]), graph = FALSE)
+               ind.hcpc = HCPC(data.frame(Idata), graph = FALSE)
                Idata$clust = ind.hcpc$data.clust$clust
                last.clust = length(levels(ind.hcpc$data.clust$clust)) + 1
              } else {
@@ -597,7 +601,6 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
              Idata = Idata[order(ind.cos2, decreasing = TRUE),] # tri par qualite de projection decroissante sur le plan (utile pour selection des 5 meilleurs individus ensuite)
              
              
-             
              for(d in desc) {
                writeRmd("\n* * *", file = file, end = "\n\n")
                
@@ -609,9 +612,12 @@ function(res, file = "", dim = 1:2, desc = dim, Iselec = "contrib", Vselec = "co
                
                if(length(ind.pos) > mmax) {
                  ind.pos = paste(paste(ind.pos[1:(mmax - 1)], collapse = "*, *"), ind.pos[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
-                 ind.neg = paste(paste(ind.neg[1:(mmax - 1)], collapse = "*, *"), ind.neg[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
                } else if(length(ind.pos) > 1) {
                  ind.pos = paste(paste(ind.pos[- length(ind.pos)], collapse = "*, *"), ind.pos[length(ind.pos)], sep = gettext("* and *",domain="R-FactoInvestigate"))
+               }
+               if(length(ind.neg) > mmax) {
+                 ind.neg = paste(paste(ind.neg[1:(mmax - 1)], collapse = "*, *"), ind.neg[mmax], sep = gettext("* and *",domain="R-FactoInvestigate"))
+               } else if(length(ind.neg) > 1) {
                  ind.neg = paste(paste(ind.neg[- length(ind.neg)], collapse = "*, *"), ind.neg[length(ind.neg)], sep = gettext("* and *",domain="R-FactoInvestigate"))
                }
                
